# © 2020 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import models, fields, api
from odoo.exceptions import ValidationError


class CgscopIncubExpertiseProjet(models.Model):
    _name = 'cgscop_incub.expertise_projet'
    _description = "Expertises du projet d'incubation"
    _order = 'incub_phase,mission_deb'

    partner_id = fields.Many2one(
        comodel_name='res.partner',
        string='Organisme',
        domain=[('is_company', '=', True)],
        ondelete='restrict', index=True)
    incub_phase = fields.Selection([
        ('2_pre-incubation', 'Phase de pré-incubation'),
        ('3_incubation', "Phase d'incubation")],
        string='Phase projet',
        required=True,
        index=True)
    expertise_id = fields.Many2one(
        comodel_name='cgscop_incub.expertise',
        string="Expertise",
        ondelete='restrict',
        required=True,
        index=True)
    supplier_id = fields.Many2one(
        comodel_name='res.partner',
        string='Prestataire',
        domain=[('active', '=', True), ('is_company', '=', True),
                ('is_cooperative', '=', False)],
        on_delete='restrict')
    montant = fields.Float(string="Montant engagé", required=True)
    commentaire = fields.Text(string='Commentaires')
    mission_deb = fields.Date(string="Début de mission")
    mission_fin = fields.Date(string="Fin de mission")
    bdc = fields.Char(string="No bon de commande")
    devis = fields.Boolean(string="Devis reçu")
    livrable = fields.Boolean(string="Livrable rendu")
    facture = fields.Boolean(string="Facture reçue")

    # ------------------------------------------------------
    # Constains
    # ------------------------------------------------------
    @api.constrains('mission_deb', 'mission_fin')
    @api.multi
    def _date_constrains(self):
        for rec in self:
            if rec.mission_fin and rec.mission_deb:
                if rec.mission_fin < rec.mission_deb:
                    raise ValidationError(
                        "La date de fin de mission doit être supérieure \
                        à la date de début")
